@@ -1,12 +1,13 @@
 package Search::OpenSearch::Facets;
-use Moo;
+use Moose;
+use MooseX::StrictConstructor;
 use Types::Standard qw( ArrayRef Int );
 use Carp;
 
 has 'names' => ( is => 'rw', isa => ArrayRef );
 has 'sample_size' => ( is => 'rw', isa => Int, default => sub {0} );
 
-our $VERSION = '0.399_04';
+our $VERSION = '0.399_05';
 
 1;
 
